@@ -66,6 +66,7 @@
 #' @examples
 #' # Load data.table
 #' library(data.table)
+#' \dontshow{data.table::setDTthreads(1)}
 #'
 #' # Read example data
 #' DT <- fread(system.file("extdata", "DT.csv", package = "spatsoc"))
@@ -112,7 +113,7 @@ group_times <- function(DT = NULL,
 
   if (is.null(threshold)) {
     message('no threshold provided, using the time field directly to group')
-    DT[, timegroup := .GRP, by = datetime]
+    DT[, timegroup := .GRP, by = c(datetime)]
     return(DT[])
   } else {
     if (length(datetime) == 1 &&
