@@ -4,22 +4,26 @@ library(spatsoc)
 
 DT <- fread('../testdata/DT.csv')
 
-utm <- 'EPSG:32736'
+DT[, datetime := as.POSIXct(datetime)]
+DT[, family := sample(c(1, 2, 3, 4), .N, replace = TRUE)]
+DT[, jul := data.table::yday(datetime)]
+
+utm <- 32736
 
 test_that('DT or spPts are required but not both', {
   expect_error(group_polys(
     DT = NULL,
-    spPolys = NULL,
+    sfPolys = NULL,
     area = FALSE
   ),
-  'must provide either DT or spPolys')
+  'must provide either DT or sfPolys')
 
   expect_error(group_polys(
     DT = DT,
-    spPolys = 10,
+    sfPolys = 10,
     area = FALSE
   ),
-  'cannot provide both DT and spPolys')
+  'cannot provide both DT and sfPolys')
 })
 
 test_that('area provided and logical, or error', {
@@ -63,6 +67,20 @@ test_that('area provided and logical, or error', {
   )
 })
 
+test_that('id provided', {
+  expect_error(
+    group_polys(
+      DT = DT,
+      projection = utm,
+      hrType = 'mcp',
+      area = TRUE,
+      coords = c('X', 'Y'),
+      id = NULL
+    ),
+    'id must be provided',
+    fixed = TRUE
+  )
+})
 
 test_that('projection provided or error', {
   expect_error(
@@ -152,19 +170,19 @@ test_that('column names must exist in DT', {
   )
 })
 
-test_that('splitBy and spPolys are not both provided', {
+test_that('splitBy and sfPolys are not both provided', {
   expect_error(
     group_polys(
       splitBy = 'yr',
-      spPolys = 10,
+      sfPolys = 10,
       area = TRUE
     ),
-    'cannot provide spPolys if providing splitBy'
+    'cannot provide sfPolys if providing splitBy'
   )
 })
 
 
-test_that('ID field is alphanumeric and does not have spaces', {
+test_that('ID field does not have spaces', {
   copyDT <- copy(DT)[ID == unique(ID)[1], ID := paste(ID, ID)]
   idpromise <- evaluate_promise(
     expect_error(group_polys(
@@ -179,7 +197,7 @@ test_that('ID field is alphanumeric and does not have spaces', {
   )
   expect_match(
     as.character(idpromise$result),
-    'please ensure IDs are alphanumeric and do not contain spaces'
+    'please ensure IDs do not contain spaces'
   )
 
   copyDT[, population := 1]
@@ -194,14 +212,13 @@ test_that('ID field is alphanumeric and does not have spaces', {
       id = 'ID',
       splitBy = 'population'
     ),
-    'please ensure IDs are alphanumeric and do not contain spaces'
+    'please ensure IDs do not contain spaces'
   )
 })
 
 test_that('column and row lengths returned make sense', {
   copyDT <- copy(DT)
-  ltepromise <- evaluate_promise(
-    group_polys(
+  group_polys_mcp <- group_polys(
       DT = copyDT,
       projection = utm,
       hrType = 'mcp',
@@ -209,16 +226,13 @@ test_that('column and row lengths returned make sense', {
       area = TRUE,
       coords = c('X', 'Y'),
       id = 'ID'
-    )
   )
-  expect_lte(nrow(ltepromise$result),
+  expect_lte(nrow(group_polys_mcp),
              nrow(expand.grid(DT[, unique(ID)], DT[, unique(ID)])))
 
-
   copyDT <- copy(DT)[, yr := year(datetime)]
 
-  ltepromise2 <- evaluate_promise(
-    group_polys(
+  group_polys_mcp_split <- group_polys(
       DT = copyDT,
       projection = utm,
       hrType = 'mcp',
@@ -228,26 +242,35 @@ test_that('column and row lengths returned make sense', {
       id = 'ID',
       splitBy = 'yr'
     )
+
+  expect_equal(nrow(group_polys_mcp_split), nrow(copyDT))
+
+  group_sf_polys <- group_polys(
+      id = 'ID',
+      area = FALSE,
+      sfPolys = build_polys(
+        DT = DT,
+        projection = utm,
+        hrType = 'mcp',
+        hrParams = list(percent = 95),
+        coords = c('X', 'Y'),
+        id = 'ID'
+    )
   )
-
-  expect_equal(nrow(ltepromise2$result), nrow(copyDT))
-
-  copyDT <- copy(DT)
-  copyDT[, family := sample(c(1, 2, 3, 4), .N, replace = TRUE)]
-  ncolpromise <- evaluate_promise({
-    group_polys(
-      DT = copyDT,
+  group_sf_polys_area <- group_polys(
+    id = 'ID',
+    area = TRUE,
+    sfPolys = build_polys(
+      DT = DT,
       projection = utm,
       hrType = 'mcp',
       hrParams = list(percent = 95),
-      area = FALSE,
       coords = c('X', 'Y'),
-      id = 'ID',
-      splitBy = 'family'
-    )}
+      id = 'ID'
+    )
   )
-  expect_equal(ncol(DT) + 2,
-               ncol(ncolpromise$result))
+  expect_equal(nrow(group_sf_polys), length(unique(DT$ID)))
+  expect_equal(nrow(group_sf_polys_area), length(unique(DT$ID)) ^ 2)
 })
 
 
@@ -258,8 +281,7 @@ test_that('withinGroup is not returned to the user', {
     group_times(copyDT, datetime = 'datetime', threshold = '14 days')
   )
   copyDT[, N := .N, by = .(ID, block)]
-  withinpromise <- evaluate_promise(
-    group_polys(
+  within_group <- group_polys(
       DT = copyDT,
       projection = utm,
       hrType = 'mcp',
@@ -267,9 +289,8 @@ test_that('withinGroup is not returned to the user', {
       area = FALSE,
       coords = c('X', 'Y'),
       id = 'ID'
-    )
   )
-  expect_false('withinGroup' %in% colnames(withinpromise$result))
+  expect_false('withinGroup' %in% colnames(within_group))
 })
 
 
@@ -313,8 +334,7 @@ test_that('group column succesfully detected', {
 test_that('area provided with splitBy does not return errors', {
   copyDT <- copy(DT)[, datetime := as.POSIXct(datetime)]
   copyDT[, yr := year(datetime)]
-  withinsplitpromise <- evaluate_promise(
-    group_polys(
+  within_split <- group_polys(
       DT = copyDT,
       projection = utm,
       hrType = 'mcp',
@@ -323,12 +343,10 @@ test_that('area provided with splitBy does not return errors', {
       coords = c('X', 'Y'),
       id = 'ID',
       splitBy = 'yr'
-    )
   )
-  expect_false('withinGroup' %in% colnames(withinsplitpromise$result))
+  expect_false('withinGroup' %in% colnames(within_split))
 
-  areapromise <- evaluate_promise(
-    group_polys(
+  area <- group_polys(
       DT = copyDT,
       projection = utm,
       hrType = 'mcp',
@@ -337,12 +355,10 @@ test_that('area provided with splitBy does not return errors', {
       coords = c('X', 'Y'),
       id = 'ID',
       splitBy = 'yr'
-    )
   )
-  expect_true('area' %in% colnames(areapromise$result))
+  expect_true('area' %in% colnames(area))
 
-  proppromise <- evaluate_promise(
-    group_polys(
+  prop <- group_polys(
       DT = copyDT,
       projection = utm,
       hrType = 'mcp',
@@ -351,9 +367,8 @@ test_that('area provided with splitBy does not return errors', {
       coords = c('X', 'Y'),
       id = 'ID',
       splitBy = 'yr'
-    )
   )
-  expect_true('proportion' %in% colnames(proppromise$result))
+  expect_true('proportion' %in% colnames(prop))
 })
 
 
@@ -389,8 +404,8 @@ test_that('less than 5 locs returns NAs and warning', {
     'build_polys failed for some rows', fixed = FALSE
   )
 
-  expect_true(suppressWarnings(
-    group_polys(
+  expect_true(
+    suppressWarnings(group_polys(
       DT = copyDT,
       projection = utm,
       hrType = 'mcp',
@@ -399,11 +414,11 @@ test_that('less than 5 locs returns NAs and warning', {
       coords = c('X', 'Y'),
       id = 'ID',
       splitBy = 'yr'
-    )[is.na(group), .N] != 0)
-  )
+    )[is.na(group), .N != 0]
+  ))
 
-  expect_true(suppressWarnings(
-    group_polys(
+  expect_true(
+    suppressWarnings(group_polys(
       DT = copyDT,
       projection = utm,
       hrType = 'mcp',
@@ -412,8 +427,103 @@ test_that('less than 5 locs returns NAs and warning', {
       coords = c('X', 'Y'),
       id = 'ID',
       splitBy = 'yr'
-    )[is.na(area), .N] != 0)
-  )
+    )[is.na(area), .N != 0]
+  ))
 
 
 })
+
+
+
+test_that('splitBy argument doesnt use splitBy column', {
+  copyDT <- copy(DT)
+
+  copyDT[, splitBy := family]
+
+  utm <- 32736
+
+  expect_true(
+    suppressWarnings(group_polys(
+      DT = copyDT,
+      projection = utm,
+      hrType = 'mcp',
+      hrParams = list(percent = 95),
+      area = FALSE,
+      coords = c('X', 'Y'),
+      id = 'ID',
+      splitBy = 'jul'
+    ))[, uniqueN(jul), group][, all(V1 == 1)]
+  )
+
+  expect_true(
+    ! 'splitBy' %in%
+      suppressWarnings(group_polys(
+        DT = copyDT,
+        projection = utm,
+        hrType = 'mcp',
+        hrParams = list(percent = 95),
+        area = TRUE,
+        coords = c('X', 'Y'),
+        id = 'ID',
+        splitBy = 'jul'
+      ))
+  )
+
+})
+
+
+test_that('proportion within 0-100, area > 0', {
+
+  out_mcp <- suppressWarnings(group_polys(
+    DT = DT,
+    projection = utm,
+    hrType = 'mcp',
+    hrParams = list(percent = 95),
+    area = TRUE,
+    coords = c('X', 'Y'),
+    id = 'ID'
+  ))
+
+  expect_gte(min(out_mcp$proportion),
+             units::as_units(0, 'percent'))
+  expect_lte(max(out_mcp$proportion),
+             units::as_units(100.01, 'percent'))
+  expect_gte(min(out_mcp$area),
+             units::as_units(0, 'm^2'))
+
+
+  out_kernel <- suppressWarnings(group_polys(
+    DT = DT,
+    projection = utm,
+    hrType = 'kernel',
+    hrParams = list(percent = 95),
+    area = TRUE,
+    coords = c('X', 'Y'),
+    id = 'ID'
+  ))
+
+  expect_gte(min(out_kernel$proportion),
+             units::as_units(0, 'percent'))
+  expect_lte(max(out_kernel$proportion),
+             units::as_units(100.01, 'percent'))
+  expect_gte(min(out_kernel$area),
+             units::as_units(0, 'm^2'))
+
+})
+
+
+test_that('sfPolys has area column', {
+  sfPolys <- build_polys(DT, projection = utm, hrType = 'kernel',
+                         hrParams = list(grid = 60, percent = 95),
+                         id = 'ID', coords = c('X', 'Y'))
+
+  sfPolys$area <- NULL
+
+  expect_error(
+    group_polys(sfPolys = sfPolys,
+                area = TRUE,
+                id = 'id'),
+    'please ensure column "area"',
+    fixed = TRUE
+  )
+})
